Coverage report

# Coverage report: 91.52%

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
Total | 780 | 62 | 6 | 104 | 13 | 91.52%
/home/chris/workspace/django-shop/shop/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/admin/__init__ | 2 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/admin/clientadmin | 12 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/admin/orderadmin | 9 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/backends_pool | 54 | 0 | 0 | 12 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/cart/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/cart/cart_modifiers_base | 9 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/cart/modifiers/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/cart/modifiers/rebate_modifiers | 11 | 0 | 0 | 2 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/cart/modifiers/tax_modifiers | 18 | 6 | 0 | 2 | 2 | 60.00%
/home/chris/workspace/django-shop/shop/cart/modifiers_pool | 32 | 0 | 0 | 6 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/models/__init__ | 4 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/models/cartmodel | 70 | 1 | 0 | 14 | 1 | 97.62%
/home/chris/workspace/django-shop/shop/models/clientmodel | 35 | 1 | 0 | 0 | 0 | 97.14%
/home/chris/workspace/django-shop/shop/models/ordermodel | 155 | 5 | 0 | 14 | 2 | 95.86%
/home/chris/workspace/django-shop/shop/models/productmodel | 28 | 2 | 0 | 0 | 0 | 92.86%
/home/chris/workspace/django-shop/shop/payment/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/payment/api | 13 | 3 | 0 | 0 | 0 | 76.92%
/home/chris/workspace/django-shop/shop/payment/backends/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/payment/backends/pay_on_delivery | 13 | 3 | 0 | 0 | 0 | 76.92%
/home/chris/workspace/django-shop/shop/payment/urls | 6 | 1 | 0 | 2 | 1 | 75.00%
/home/chris/workspace/django-shop/shop/shipping/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/shipping/api | 20 | 1 | 0 | 4 | 0 | 95.83%
/home/chris/workspace/django-shop/shop/shipping/backends/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/shipping/backends/flat_rate | 19 | 5 | 0 | 0 | 0 | 73.68%
/home/chris/workspace/django-shop/shop/shipping/urls | 9 | 0 | 0 | 2 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/shop_api | 21 | 8 | 0 | 0 | 0 | 61.90%
/home/chris/workspace/django-shop/shop/templatetags/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/templatetags/shop_tags | 18 | 2 | 0 | 0 | 0 | 88.89%
/home/chris/workspace/django-shop/shop/urls | 8 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/util/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/util/cart | 21 | 0 | 0 | 10 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/util/fields | 17 | 4 | 0 | 6 | 0 | 82.61%
/home/chris/workspace/django-shop/shop/util/order | 23 | 0 | 0 | 12 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/views/__init__ | 6 | 0 | 6 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/views/cart | 79 | 2 | 0 | 12 | 2 | 95.60%
/home/chris/workspace/django-shop/shop/views/checkout | 38 | 17 | 0 | 4 | 4 | 50.00%
/home/chris/workspace/django-shop/shop/views/order | 20 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/views/product | 10 | 1 | 0 | 2 | 1 | 83.33%